@@ -6,13 +6,13 @@ import sys
 import argparse
 from collections import defaultdict
 from mycotools.lib.biotools import fa2dict, dict2fa, reverse_complement
-from mycotools.lib.dbtools import mtdb, primaryDB
+from mycotools.lib.dbtools import mtdb, masterDB
 from mycotools.lib.kontools import format_path, eprint, stdin2str
 
 def extract_mtdb_accs_exp(fa_dict, accs):
     return {acc: fa_dict[acc] for acc in accs}
 
-def extract_mtdb_accs(fa_dict, accs, spacer = ''):
+def extract_mtdb_accs(fa_dict, accs):
     """extract MTDB accessions from fa_dict using a list `accs`; can 
     extract coordinates of an accession if labeled 
     `acc[START:END] | acc[START-END]`. If start > end, extract the reverse
@@ -20,7 +20,7 @@ def extract_mtdb_accs(fa_dict, accs, spacer = ''):
 
     out_fa = {}
     for acc in accs:
-        coords = acc[acc.find('[')+1:acc.find(']')]
+        coords = acc[acc.find('['):acc.find(']')]
         if coords: # if there are coordinates
             try: # try splitting by colon
                 start, end = [int(x) for x in coords.split(':')]
@@ -30,35 +30,24 @@ def extract_mtdb_accs(fa_dict, accs, spacer = ''):
                 except ValueError: # invalid coordinates, try whole acc
                     out_fa[acc] = fa_dict[acc]
                     continue
-            acc_name = acc[:acc.find('[')]
+            acc_name = acc[:start]
             if start < end:
-                try:
-                    out_fa[acc] = {
-                        'sequence': fa_dict[acc_name]['sequence'][start:end+1],
-                        'description': fa_dict[acc_name]['description']
-                        }
-                except KeyError:
-                    eprint(spacer + 'WARNING: invalid accession ' + acc_name, 
-                           flush = True)
+                out_fa[acc] = {
+                    'sequence': fa_dict[acc_name]['sequence'][start:end+1],
+                    'description': fa_dict[acc_name]['description']
+                    }
             else:
-                try:
-                    out_fa[acc] = {
-                        'sequence': reverse_complement(
+                out_fa[acc] = {
+                    'sequence': reverse_complement(
                         fa_dict[acc_name]['sequence'][end-1:start+1]
                         ),
-                        'description': fa_dict[acc_name]['description']
-                        }
-                except KeyError:
-                    eprint(spacer + 'WARNING: invalid accession ' + acc_name,
-                           flush = True)
+                    'description': fa_dict[acc_name]['description']
+                    }
         else: # no coordinates
-            try:
-                out_fa[acc] = fa_dict[acc] # extract the whole accession
-            except KeyError:
-                eprint(spacer + 'WARNING: invalid accession ' + acc_name,
-                       flush = True)
+            out_fa[acc] = fa_dict[acc] # extract the whole accession
 
     return out_fa
+            
 
 def extractHeaders(fasta_file, accessions, ome = None):
     """searches headers for "[]", which indicate coordinate-based extraction.
@@ -101,9 +90,9 @@ def extractHeaders(fasta_file, accessions, ome = None):
                 out_fasta[header] = fasta[header]
 
     return out_fasta
+   
 
-def dbmain(db, accs, error = True, 
-           spacer = '\t\t\t', coord_check = True):
+def dbmain(db, accs, error = True, spacer = '\t\t\t', coord_check = True):
     """takes in mtdb, takes accessions ome by ome from accs;
     error will exit if set to true, report to stderr if not;
     coord_check will check entries for coordinate signatures in accession names
@@ -128,7 +117,7 @@ def dbmain(db, accs, error = True,
                 ome_fasta = fa2dict(db[ome]['faa'])
             except KeyError: # if there is a missing ome
                 if error:
-                    raise KeyError('invalid ome: ' + ome)
+                    raise KeyError
                 else:
                     eprint(spacer + ome + ' not in database', flush = True)
             fa_dict = {**fa_dict, **extract_mtdb_accs(ome_fasta, ome_accs)}
@@ -142,11 +131,12 @@ def dbmain(db, accs, error = True,
                 else:
                     eprint(spacer + ome + ' not in database', flush = True)
             fa_dict = {**fa_dict, **extract_mtdb_accs_exp(ome_fasta, ome_accs)}
+ 
 
     return fa_dict
 
 
-def famain(accs, fa, ome = None):
+def famain( accs, fa, ome = None ):
     """takes in accessions, fasta, and retrieves accessions"""
 
     fa_dict = {}
@@ -166,7 +156,7 @@ if __name__ == '__main__':
         help = 'Accessions column for -i (1 indexed). DEFAULT: 1', type = int)
     parser.add_argument('-s', '--start', help = 'Start index column (1 indexed)', type = int)
     parser.add_argument('-e', '--end', help = 'End index column (1 indexed)', type = int)
-    parser.add_argument('-d', '--mtdb', default = primaryDB())
+    parser.add_argument('-d', '--mtdb', default = masterDB())
     args = parser.parse_args()
 
     if args.input: # input file
@@ -175,28 +165,20 @@ if __name__ == '__main__':
             with open(input_file, 'r') as raw:
                 accs = []
                 for line in raw:
-                    if not line.startswith('#') and line.rstrip():
+                    if not line.startswith('#'):
                         d = line.rstrip().split('\t')
                         accs.append([
                             d[args.column-1] + '[' + d[args.start-1] + '-' + d[args.end-1] + ']'
                             ])
         else:
             with open(input_file, 'r') as raw:
-                accs = [x.rstrip().split('\t')[args.column-1] \
-                        for x in raw if x.rstrip()]
+                accs = [x.rstrip().split('\t')[args.column-1] for x in raw]
     else: # assume we are using accessions
         if '-' == args.accession: # stdin
             data = stdin2str()
             accs = data.split()
         else:
-            if {'"', "'"}.intersection(set(args.accession)):
-                args.accession = args.accession.replace('"','').replace("'",'')
-            if ',' in args.accession:
-                accs = args.accession.split(',')
-            elif re.search(r'\s', args.accession):
-                accs = args.accession.split()
-            else:
-                accs = [args.accession]
+            accs = [args.accession]
        
     db_path = format_path(args.mtdb)
     if not args.fasta: # MTDB run
