@@ -1,8 +1,5 @@
 #! /usr/bin/env python3
 
-# NEED multiple lineages from command line
-# NEED stdin acceptance for most of these arguments
-
 import os
 import sys
 import copy
@@ -10,22 +7,7 @@ import random
 import argparse
 from collections import defaultdict
 from mycotools.lib.kontools import file2list, intro, outro, format_path, eprint
-from mycotools.lib.dbtools import mtdb, primaryDB
-
-def infer_rank(db, lineage):
-    linlow, rank = lineage.lower(), None
-    for ome, row in db.items():
-        if linlow in set([x.lower() for x in row['taxonomy'].values()]):
-            rev_dict = {k.lower(): v \
-                        for k,v in zip(row['taxonomy'].values(), 
-                                       row['taxonomy'].keys())}
-            rank = rev_dict[lineage]
-
-    if not rank:
-        raise KeyError(f'no entry for {lineage}')
-
-    return rank
-                            
+from mycotools.lib.dbtools import mtdb, masterDB
 
 def extract_unique(db, allowed = 1, sp = True):
     keys = copy.deepcopy(list(db.keys()))
@@ -50,22 +32,17 @@ def extract_unique(db, allowed = 1, sp = True):
             found = set(found_prep)
     return prep_db1
 
-def extract_tax(db, lineages):
+def extract_tax(db, lineages, classification):
     if isinstance(lineages, str):
         lineages = [lineages]
     lineages = set(x.lower() for x in lineages)
-    rank_dict = {k: infer_rank(db, k) for k in list(lineages)}
-    ranks = list(set(rank_dict.values()))
-
-
     new_db = mtdb().set_index()
     for ome in db:
-        for rank in ranks:
-            try:
-                if db[ome]['taxonomy'][rank].lower() in lineages:
-                    new_db[ome] = db[ome]
-            except KeyError: # invalid rank key for row
-                pass # probably should standardize tax jsons period
+        try:
+            if db[ome]['taxonomy'][classification].lower() in lineages:
+                new_db[ome] = db[ome]
+        except KeyError:
+            pass
 
     return new_db
 
@@ -90,7 +67,7 @@ def extract_pub(db):
 
 def main( 
     db, unique_strains = False, unique_species = 0, 
-    lineage_list = [], omes_set = set(),
+    lineage_list = [], rank = None, omes_set = set(),
     source = None, nonpublished = False, inverse = False
     ):
 
@@ -102,7 +79,7 @@ def main(
 
     # extract each taxonomic entry based on the classification specified
     if lineage_list:
-        new_db = extract_tax(db, lineage_list)
+        new_db = extract_tax(db, lineage_list, rank)
     # if an ome list is specified then open it, store each entry in a list and pull each ome
     elif omes_set:
         new_db = extract_ome(db, omes)
@@ -130,14 +107,12 @@ def main(
 
 
 if __name__ == '__main__':
-    if {'-r', '--rank'}.intersection(set(sys.argv)):
-        eprint('\nERROR: -r/--rank are no longer necessary')
-        sys.exit(5)
+
     parser = argparse.ArgumentParser( description = \
        'Extracts a MycotoolsDB from arguments. E.g.\t`extractDB.py ' + \
-       '-l Atheliaceae`' )
+       '-l Atheliaceae -r family`' )
     parser.add_argument('-l', '--lineage')
-#    parser.add_argument('-r', '--rank', help = "Taxonomy rank")
+    parser.add_argument('-r', '--rank', help = "Taxonomy rank")
     parser.add_argument('-s', '--source')
     parser.add_argument('-n', '--nonpublished', action = 'store_true', 
         help = 'Include restricted')
@@ -147,21 +122,20 @@ if __name__ == '__main__':
     parser.add_argument('-i', '--inverse', action = 'store_true', 
         help = 'Inverse [source|lineage(s)|nonpublished]')
     parser.add_argument('-ol', '--ome', help = "File w/list of omes" )
-    parser.add_argument('-ll', '--lineages', help = 'File w/list of lineages' )
+    parser.add_argument('-ll', '--lineages', help = 'File w/list of lineages (same rank)' )
     parser.add_argument('--headers', action = 'store_true')
     parser.add_argument('-', '--stdin', action = 'store_true')
-    parser.add_argument('-d', '--mtdb', default = primaryDB())
+    parser.add_argument('-d', '--mtdb', default = masterDB())
     parser.add_argument('-o', '--output' )
     args = parser.parse_args()
     db_path = format_path( args.mtdb )
 
 
-#    if (args.lineage or args.lineages) and not args.rank:
- #       eprint('\nERROR: need rank for lineage(s)', flush = True)
-  #      sys.exit(5)
-    if args.lineage or args.lineages:
-        eprint("\nWARNING: extracting taxonomy is subject to " \
-             + "errors in NCBI's hierarchy\n")
+    if (args.lineage or args.lineages) and not args.rank:
+        eprint('\nERROR: need rank for lineage(s)', flush = True)
+        sys.exit(5)
+    elif args.lineage or args.lineages:
+        eprint("\nWARNING: extracting taxonomy is subject to taxonomic error and errors in NCBI's hiearchy\n")
 
     output = 'stdout'
     if args.output:
@@ -179,6 +153,21 @@ if __name__ == '__main__':
                 tag += '_pub'
             output += '/' + os.path.basename( db_path ) + tag
         
+    args_dict = {
+        'database': db_path,
+        'output': output,
+        'lineage': args.lineage,
+        'lineages list': args.lineages,
+        'rank': args.rank,
+        'ome_list': args.ome,
+        'Source': args.source,
+        'unique': args.allowed_sp,
+        'nonpublished': args.nonpublished,
+        'inverse': args.inverse,
+        'headers': bool(args.headers)
+    	}
+#    start_time = intro( 'Abstract Database', args_dict, stdout = args.output )
+
     if args.stdin:
         data = ''
         for line in sys.stdin:
@@ -194,14 +183,14 @@ if __name__ == '__main__':
         omes = set()
 
     if args.lineages:
-        lineage_list = file2list(format_path(args.lineages))
+        lineage_list = file2list(format_path(lineage_list))
     elif args.lineage:
         lineage_list = [args.lineage]
     else:
         lineage_list = []
 
     new_db = main( 
-        db, lineage_list = lineage_list,
+        db, rank = args.rank, lineage_list = lineage_list,
         omes_set = omes, source = args.source, unique_species = args.allowed_sp, 
         nonpublished = args.nonpublished, inverse = args.inverse
         )
@@ -210,4 +199,5 @@ if __name__ == '__main__':
     else:
         new_db.df2db( headers = bool(args.headers) )
 
+ #   outro( start_time, stdout = args.output )
     sys.exit(0)
