@@ -14,7 +14,7 @@ from mycotools.extractHmmAcc import main as extr_hmm
 from mycotools.db2search import compAcc2fa
 from mycotools.acc2fa import famain as acc2fa
 from mycotools.lib.kontools import intro, outro, findExecs, eprint, format_path
-from mycotools.lib.dbtools import mtdb, primaryDB
+from mycotools.lib.dbtools import mtdb, masterDB
 from mycotools.lib.biotools import dict2fa
 
 def runextractHmmAcc(hmm, accession, output):
@@ -39,7 +39,7 @@ def runHmmer(fasta, hmm, output, cpu = 1, binary = 'hmmsearch'):
     return hmm_status
 
 
-def run_extract_hmm(
+def runExtractHmm(
     hmm_out, top_hits, cov_threshold, evalue, query = True, acc = None
     ):
 
@@ -59,7 +59,7 @@ def run_extract_hmm(
     return hmm_data
 
 
-def parse_hmm_data(hmm_data):
+def parseHmmData(hmm_data):
 
     output_res = {}
     for query in hmm_data:
@@ -79,7 +79,7 @@ def parse_hmm_data(hmm_data):
     return output_res
 
 
-def run_acc2fa(db, biotype, output_res, subhit = True, cpu = 1):
+def runAcc2fa(db, biotype, output_res, subhit = True, cpu = 1):
 
     acc2fa_cmds = compAcc2fa(db, biotype, output_res, subhit)
     output_fas = {}
@@ -134,14 +134,14 @@ def main(
         sys.exit(2)
     
     print('\nParsing output', flush = True)
-    hmm_data = run_extract_hmm(
+    hmm_data = runExtractHmm(
         hmmer_out, top_hits, cov_threshold, evalue, 
         not accession_search, accession
         )
-    output_res = parse_hmm_data(hmm_data)
+    output_res = parseHmmData(hmm_data)
 
     print('\nCompiling fastas', flush = True)
-    output_fas = run_acc2fa(db, biotype, output_res, subhit = subhit, cpu = cpu)
+    output_fas = runAcc2fa(db, biotype, output_res, subhit = subhit, cpu = cpu)
 
     return output_fas
 
@@ -154,7 +154,7 @@ if __name__ == '__main__':
     parser.add_argument('-f', '--fasta', required = True, help = 'Input .fasta')
     parser.add_argument('--hmm', required = True, help = 'Input .hmm')
     parser.add_argument('-b', '--binary', required = True, help = "{'hmmsearch', 'nhmmer'}")
-    parser.add_argument('-d', '--mtdb', default = primaryDB(), help = 'MycoDB. DEFAULT: master')
+    parser.add_argument('-d', '--mtdb', default = masterDB(), help = 'MycoDB. DEFAULT: master')
     parser.add_argument('-q', '--query', help = 'Query [acc if -a] from .hmm, or new line delimited file')
     parser.add_argument('-c', '--coverage', type = float, help = 'Decimal minimum percent hmm coverage')
     parser.add_argument('-w', '--whole', action = 'store_true', help = 'Extract entire hit sequence' )
