@@ -4,7 +4,7 @@ import re
 import sys
 import argparse
 from Bio.Seq import Seq
-from mycotools.lib.dbtools import mtdb, primaryDB
+from mycotools.lib.dbtools import mtdb, masterDB
 from mycotools.lib.biotools import fa2dict, gff2list, gff3Comps, dict2fa
 from mycotools.lib.kontools import format_path, sys_start, eprint, stdin2str
 
@@ -42,6 +42,8 @@ def sortContig(contigData):
 
     return outContig
 
+
+
 def sortGFF(unsorted_gff, idComp):
 
     sorting_groups, oldGene = {}, None
@@ -90,12 +92,12 @@ def grabCDS(gff_dicts, spacer = '\t'):
         elif entry['type'] == 'gene':
             try:
                 alias = re.search(gff3Comps()['Alias'], entry['attributes'])[1]
-                genes.extend(alias.split('|'))
             except TypeError:
                 if not warning and ome:
                     eprint(spacer + 'WARNING: ' + str(ome) + ' missing aliases', flush = True)
                     warning = True
-                raise TypeError(str(entry))
+#                raise TypeError(str(entry))
+            genes.extend(alias.split('|')) # account for alternate splicing
 
     mrna_set = set([x for x in mrnas if x in set(genes)])
     out_cds = []
@@ -105,6 +107,7 @@ def grabCDS(gff_dicts, spacer = '\t'):
             if alias in mrna_set:
                 out_cds.append(entry)
 
+
     return out_cds
 
 def order_neg_dict( neg_dict ):
@@ -543,9 +546,8 @@ def ntmain(gff_dicts, assem_dict, coding = True,
 
 def aamain( gff_dicts, assem_dict, spacer = '\t' ):
     
-    cdss = grabCDS(gff_dicts, spacer)
-    pos_dict, neg_dict = grabCoords(cdss)
-
+    cdss = grabCDS( gff_dicts, spacer )
+    pos_dict, neg_dict = grabCoords( cdss )
 
     genes_fa_dict = {}
     for contig in pos_dict:
@@ -589,7 +591,7 @@ if __name__ == '__main__':
         assembly_dicts = {'input': fa2dict( format_path(args.assembly) )}
         gff_dicts = {'input': input_gff}
     else:
-        db = mtdb(primaryDB()).set_index('ome')
+        db = mtdb(masterDB()).set_index('ome')
         gff_dicts, assembly_dicts = {}, {}
         try:
             for line in input_gff:
