@@ -100,11 +100,8 @@ def fa2dict(fasta_input, file_ = True):
             descrip = ''
 
         seq = val[1]
-        if seq:
-            if seq[-1] == '\n' or seq[-1] == '\r':
-                seq = seq.rstrip()
-        else:
-            continue
+        if seq[-1] == '\n' or seq[-1] == '\r':
+            seq = seq.rstrip()
 
         # prepares dictionaries for each gene with description, seq, rvcmpl_seq, and codons
         fasta_dict[gene] = {}
@@ -172,7 +169,7 @@ def dict2fa(fasta_dict, description = True):
             fasta_string += '>' + gene.rstrip() + '\n' + \
             fasta_dict[ gene ][ 'sequence' ].rstrip() + '\n'
 
-    return fasta_string
+    return fasta_string.rstrip()
 
 # need to turn these into classes and class functions
 def calc_gc(gene):
@@ -184,6 +181,8 @@ def calc_gc(gene):
 
     return(GC_con)
 
+
+
 # need to change into a class
 def gff2list(gff_info, path = True, error = True):
 
@@ -205,10 +204,10 @@ def gff2list(gff_info, path = True, error = True):
                 })
     except IndexError:
         raise IndexError(str(len(col_list)) + '/9 expected tab-' \
-                        + 'delimitted fields: ' + str(col_list))
+                        + 'delimitted fields: ' + str(line))
     except ValueError:
         raise ValueError(str(col_list[4:6]) + ' invalid integer ' \
-                        + 'conversion: ' + str(col_list))
+                        + 'conversion: ' + str(line))
             
     return gff_list_dict
 
@@ -228,16 +227,14 @@ def list2gff(gff_list, ver = 3):
 def gff3Comps( source = None ):
 
     comps = {}
-    comps['par'] = '(?:^|(?<=;))' + r'Parent=["\']?([^;\'"]+)'
-    comps['id'] = '(?:^|(?<=;))' + r'ID=["\']?([^;\'"]+)'
-    comps['Alias'] = '(?:^|(?<=;))' + r'Alias=["\']?([^;\'"]+)'
-    comps['product'] = '(?:^|(?<=;))' + r"""product=["\']?([^;"']+)"""
-    comps['OG'] = '(?:^|(?<=;))' + r'OG=["\']?([\w+:\d+\|]+)'
+    comps['par'] = r'Parent=["\']?([^;\'"]+)'
+    comps['id'] = r'ID=["\']?([^;\'"]+)'
+    comps['Alias'] = r'Alias=["\']?([^;\'"]+)'
+    comps['product'] = r"""product=["\']?([^;"']+)"""
+    comps['OG'] = r'OG=["\']?([\w+:\d+\|]+)'
     comps['ver'] = 'gff3'
-    comps['prot'] = '(?:^|(?<=;))' + r'protein_id=["\']?([^;\'"]+)|' \
-                  + '(?:^|(?<=;))' + r'proteinId=["\']?([^"\';]+)'
-    comps['transcript'] = '(?:^|(?<=;))' + r'transcriptId=["\']?([^;"\'])|' \
-                  + '(?:^|(?<=;))' + r'transcript_id=["\']?([^;\'"]+)'
+    comps['prot'] = r'protein_id=["\']?([^;\'"]+)|proteinId=["\']?([^"\';]+)'
+    comps['transcript'] = r'transcriptId=["\']?([^;"\'])'
    
     return comps
 
@@ -245,7 +242,6 @@ def gff2Comps():
 
     comps = {}
     comps['id'] = r'name "([^"]+)"'
-    # this unfortunately includes "gene_name" from gtf naming
     comps['prot'] = r'proteinId ([^;]+)'
     comps['transcript'] = r'transcriptId ([^;]+)'
     comps['alias'] = r'alias "([^"]+)"'
@@ -257,7 +253,7 @@ def gff2Comps():
 def gtfComps():
 
     comps = {}
-    comps['id'] = r'gene_id "?([^"]+)"?'
+    comps['id'] = r'gene_id "([^"]+)"'
     comps['transcript'] = r'transcript_id "([^"]+)"'
     comps['alias'] = r'alias "([^"]+)"'
     comps['ver'] = 'gtf'
