@@ -32,7 +32,7 @@ class mtdb(dict):
        ]
 
     # NEED a detect index feature for adding dicts in with alternative indices
-    def __init__(self, db = None, index = None, add_paths = True):
+    def __init__(self, db = None, index = None):
         self.columns = [
             'ome', 'genus', 'species', 'strain', 'taxonomy',
             'version', 'source', 'biosample', 'assembly_acc',
@@ -58,14 +58,13 @@ class mtdb(dict):
                         == set(self.columns):
                         super().__init__(db)
         else:
-            super().__init__(mtdb.db2df(self, db, add_paths = add_paths))
+            super().__init__(mtdb.db2df(self, db))
         self.index = index
 
-    def mtdb2pd(self):
-        import pandas as pd
-        copy_mtdb = copy.deepcopy(self)
-        copy_mtdb = copy_mtdb.reset_index()
-        return pd.DataFrame(copy_mtdb) # assume pd is imported
+   # def mtdb2pd(self):
+  #      copy_mtdb = copy.deepcopy(self)
+ #       copy_mtdb = copy_mtdb.reset_index()
+#        return pd.DataFrame(copy_mtdb) # assume pd is imported
 
     def pd2mtdb(df): # legacy integration
         df = df.fillna('')
@@ -81,13 +80,24 @@ class mtdb(dict):
             })
         return db
         
-    def db2df(self, db_path, add_paths = True):
+    def db2df(self, db_path):
         df = defaultdict(list)
         if os.stat(db_path).st_size == 0:
             return {x: [] for x in mtdb.columns}
         with open(format_path(db_path), 'r') as raw:
             data = [x.rstrip().split('\t') for x in raw if not x.startswith('#')]
-        columns = self.columns
+        if len(data[0]) == 16: # legacy conversion TO BE DEPRECATED
+            eprint('\tWARNING: Legacy MycotoolsDB format will be removed in the future.', flush = True)
+            columns = [
+                'ome', 'genus', 'species', 'strain', 'version',
+                'biosample', 'fna', 'faa', 'gff3', 'taxonomy', 'ecology',
+                'eco_conf',
+                'source', 'published', 'assembly_acc', 'acquisition_date'
+                ]
+            legacy = True
+        else:
+            legacy = False
+            columns = self.columns
         for entry in data:
             [df[c].append('') for c in columns] # add a blank entry to each
             # column
@@ -105,28 +115,25 @@ class mtdb(dict):
                 df['genus'][-1] + ' ' + df['species'][-1]
             df['taxonomy'][-1]['strain'] = \
                 df['strain'][-1]
-        
-        if not add_paths:
-            return df
-        try:
+        if len(data[0]) == 16: # LEGACY conversion to be deprecated
+            del df['ecology']
+            del df['eco_conf']
+        if legacy:
+            for i, ome in enumerate(df['ome']):
+                df['fna'][i] = os.environ['MYCOFNA'] + ome + '.fna'
+                df['faa'][i] = os.environ['MYCOFAA'] + ome + '.faa'
+                df['gff3'][i] = os.environ['MYCOGFF3'] + ome + '.gff3'
+        else:
             for i, ome in enumerate(df['ome']): 
                 if not df['fna'][i]:
-                    if {'MYCOFNA', 'MYCOFAA', 'MYCOGFF3'}.difference(set(os.environ.keys())):
-                        raise FileNotFoundError('You are not connected to a primary MTDB. ' \
-                                              + 'Standalone databases need absolute paths')
                     df['fna'][i] = os.environ['MYCOFNA'] + ome + '.fna'
                     df['faa'][i] = os.environ['MYCOFAA'] + ome + '.faa'
                     df['gff3'][i] = os.environ['MYCOGFF3'] + ome + '.gff3'
                 elif df['fna'][i] == ome + '.fna':
-                    if {'MYCOFNA', 'MYCOFAA', 'MYCOGFF3'}.difference(set(os.environ.keys())):
-                        raise FileNotFoundError('You are not connected to a primary MTDB. ' \
-                                              + 'Standalone databases need absolute paths')
                     df['fna'][i] = os.environ['MYCOFNA'] + ome + '.fna'
                     df['faa'][i] = os.environ['MYCOFAA'] + ome + '.faa'
                     df['gff3'][i] = os.environ['MYCOGFF3'] + ome + '.gff3'
-        except KeyError:
-            eprint('ERROR: MycotoolsDB not in path, cannot delineate biofile paths', flush = True)
-    
+
         return df
 
     def df2db(self, db_path = None, headers = False):
@@ -155,8 +162,6 @@ class mtdb(dict):
                         output[ome]['taxonomy'] = json.dumps(output[ome]['taxonomy'])
                     else:
                         output[ome]['taxonomy'] = '{}'
-                    if not output[ome]['published']:
-                        output[ome]['published'] = ''
                     out.write(
                         ome + '\t' + \
                         '\t'.join([str(output[ome][x]) for x in output[ome]]) + '\n'
@@ -267,7 +272,8 @@ def getLogin( ncbi, jgi ):
 
     return ncbi_email, ncbi_api, jgi_email, jgi_pwd
 
-def loginCheck(info_path = '~/.mycotools/mtdb_key', ncbi = True, jgi = True):
+def loginCheck( info_path = '~/.mycotools/mtdb_key', ncbi = True, jgi = True ):
+
     salt = b'D9\x82\xbfSibW(\xb1q\xeb\xd1\x84\x118'
     #NEED to make this store a password
     if os.path.isfile( format_path(info_path) ):
@@ -304,8 +310,8 @@ def loginCheck(info_path = '~/.mycotools/mtdb_key', ncbi = True, jgi = True):
     else:
         ncbi_email, ncbi_api, jgi_email, jgi_pwd = getLogin(ncbi, jgi)
         if ncbi and jgi:
-            hash_check = input('Would you like to encrypt your login ' + \
-                'information to ' + info_path + ' [Y/n]: ')
+            hash_check = input( 'Would you like to encrypt your login ' + \
+                'information to ' + info_path + ' [Y/n]: ' )
         else:
             hash_check = 'n'
         if hash_check not in {'n', 'N'}:
@@ -336,6 +342,21 @@ def loginCheck(info_path = '~/.mycotools/mtdb_key', ncbi = True, jgi = True):
 #
     return ncbi_email, ncbi_api, jgi_email, jgi_pwd
 
+def gen_config( 
+    branch = 'fungi', forbidden = '$MYCODB/log/forbidden.tsv',
+    repo = "https://gitlab.com/xonq/mycotoolsdb", 
+    rogue = False, nonpublished = False
+    ):
+
+    config = { 
+        'forbidden': forbidden,
+        'repository': repo, 
+        'branch': branch,
+        'nonpublished': nonpublished,
+        'rogue': rogue,
+    }
+
+    return config
 
 # opens a `log` file path to read, searches for the `ome` code followed by a whitespace character, and edits the line with `edit` 
 def log_editor( log, ome, edit ):
@@ -374,7 +395,7 @@ def readLog( log, columns = '', sep = '\t' ):
 
     return log_dict
 
-def primaryDB(path = '$MYCODB'):
+def masterDB(path = '$MYCODB'):
     """Acquire the path of the master database by searching $MYCODB for a file
     with a basename that starts with a date string %Y%m%d."""
 
@@ -636,12 +657,6 @@ def gather_taxonomy(df, api_key = None, king='fungi', ome_index = 'ome',
                 break
             except IndexError:
                 lineages = []
-            except HTTPError:
-                time.sleep(1)
-                handle = Entrez.efetch(db="Taxonomy", id=tax, remode = "xml")
-                records = Entrez.read(handle)
-                lineages = records[0]['LineageEx']
-                break
 
 # for each lineage, if it is a part of the kingdom, `king`, use that TaxID
 # if there are multiple TaxIDs, use the first one found
@@ -717,10 +732,6 @@ def assimilate_tax(db, tax_dicts, ome_index = 'ome', forbid={'no rank', 'superki
 
     return db
 
-def mtdb_disconnect(config, mtdb_config_file = format_path('~/.mycotools/config.json')):
-    config['active'] = False
-    write_json(config, mtdb_config_file)
-
 def mtdb_connect(config, dbtype, 
                  mtdb_config_file= format_path('~/.mycotools/config.json')):
     config['active'] = dbtype
@@ -729,14 +740,13 @@ def mtdb_connect(config, dbtype,
         os.environ[var] = env
 
 def mtdb_initialize(mycodb_loc, 
-                    mtdb_config_file= format_path('~/.mycotools/config.json'),
-                    init = False):
+                    mtdb_config_file= format_path('~/.mycotools/config.json')):
     mtdb_config = read_json(mycodb_loc + 'config/mtdb.json')
     dbtype = mtdb_config['branch']
     eprint('Establishing ' + dbtype + ' connection', flush = True)
     config = {}
 
-    if not os.path.isdir(mycodb_loc + 'mycodb') and not init:
+    if not os.path.isdir(mycodb_loc + 'mycodb'):
         raise FileNotFoundError('invalid MycotoolsDB path')
     dPath = mycodb_loc + 'data/'
     config[dbtype] = {
@@ -751,10 +761,9 @@ def mtdb_initialize(mycodb_loc,
 interface = format_path('~/.mycotools/config.json')
 if os.path.isfile(interface):
     envs_info = read_json(interface)
-    if envs_info['active']:
-        for var, env in envs_info[envs_info['active']].items():
-            os.environ[var] = env
+    for var, env in envs_info[envs_info['active']].items():
+        os.environ[var] = env
 
-#if not primaryDB():
-#    eprint('WARNING: Primary MycotoolsDB not connected; setup using `mtdb u/-i/-p/-f`', flush = True)
+if not masterDB():
+    eprint('WARNING: MycotoolsDB not initialized; setup using `mtdb -h`', flush = True)
 
