@@ -9,7 +9,6 @@ import json
 import shutil
 import tarfile
 import subprocess
-from tqdm import tqdm
 from datetime import datetime
 
 def checksum(path, cmd = 'sha256', ref = ''):
@@ -17,6 +16,7 @@ def checksum(path, cmd = 'sha256', ref = ''):
         hash_res = subprocess.run([cmd + 'sum', path],
                                  stdout = subprocess.PIPE)
         hash_info = hash_res.stdout.decode('utf-8')
+        print(hash_info)
         hash_find = re.search(r'\w+', hash_info)
         hash_ = hash_find[0]
         if ref:
@@ -285,7 +285,7 @@ def findExecs( deps, exit = set(), verbose = True ):
     checks = []
     if type(deps) is str:
         deps = [deps]
-    for dep in sorted(deps):
+    for dep in deps:
         check = shutil.which( dep )
         vprint('{:<15}'.format(dep + ':', flush = True) + \
             str(check), v = verbose, e = True)
@@ -330,7 +330,7 @@ def expandEnvVar( path ):
     return path.replace('//','/')
 
 
-def format_path(path, force_dir = False):
+def format_path(path):
     '''Goal is to convert all path types to absolute path with explicit dirs'''
 
 #    path = path.replace('//','/') 
@@ -345,18 +345,14 @@ def format_path(path, force_dir = False):
       #      return None again, let this be handled on the other end to increase
       #      throughput
     
-        if force_dir:
-            if not path.endswith('/'):
-                path += '/'
+        if path.endswith('/'):
+            if not os.path.isdir( path ):
+                path = path[:-1]
         else:
-            if path.endswith('/'):
-                if not os.path.isdir( path ):
-                    path = path[:-1]
-            else:
-                if os.path.isdir( path ):
-                    path += '/'
-            if not path.startswith('/'):
-                path = os.getcwd() + '/' + path
+            if os.path.isdir( path ):
+                path += '/'
+        if not path.startswith('/'):
+            path = os.getcwd() + '/' + path
     
     return path
 
@@ -455,36 +451,6 @@ def sys_start( args, usage, min_len, dirs = [], files = [] ):
 
     return args
 
-
-def inject_args(args, injection_calls):
-    manual_cmds = []
-    for in_call in injection_calls:
-        if in_call in args:
-            prohibited = {';', '&', '&&', '\n', '\r'}
-            man_index = args.index(in_call)
-            for char in args[man_index + 1]:
-                if char == '"' or char == "'":
-                    quote_char = char
-    
-            manual_cmd, start = [], False
-            for i, v in args[man_index + 1:]:
-                if quote_char in v:
-                    if not start:
-                        start = True
-                        manual_cmd.append(v[v.find(quote_char):])
-                    else:
-                        manual_cmd.append(v[:v.find(quote_char)])
-                        break
-                else:
-                    manual_cmd.append(v)
-            for index in reversed(range(man_index, i + 1)):
-                del args[index]
-        else:
-            manual_cmd = []
-        manual_cmds.append(manual_cmd)
-    
-    return args, manual_cmds
-
  
 def intro( script_name, args_dict, credit='', log = False, stdout = True):
     '''
@@ -660,72 +626,8 @@ def file2list(file_, types = '', sep = None, col = None, compress = False):
     return data1_list
 
 
-class Subqueue():
-    """Run a subqueue of args; can run commands consecutively to avoid shell
-    limitations while maintaining shell injection security"""
-
-    def __init__(self, args, shell = False, verbose = False, injectable = False):
-        self.injectable = injectable
-        if verbose == 1 or verbose == True:
-            self.stdout = None
-            self.stderr = None
-        elif verbose == 2:
-            self.stdout = subprocess.DEVNULL
-            self.stderr = None
-        else:
-            self.stdout = subprocess.DEVNULL
-            self.stderr = subprocess.DEVNULL
-        if isinstance(args, list) \
-            or isinstance(args, tuple) \
-            or isinstance(args, set):
-            if isinstance(list(args)[0], str):
-                self.args = (tuple(args),)
-            elif isinstance(list(args)[0], list) \
-                or isinstance(list(args)[0], tuple) \
-                or isinstance(list(args)[0], set):
-                self.args = tuple([tuple(x) for x in args])
-            else:
-                raise TypeError('invalid argument subtype: ' \
-                              + str(type(list(args[0]))))
-                   
-        elif isinstance(args, str):
-            self.args = ((args,),)
-        else:
-            raise TypeError('invalid arguments type: ' + str(type(args)))
-        self.complete = False
-        self.shell = shell
-        self.status = [-1 for x in args]
-        self.exit = -1
-
-    def open(self):
-        for i, arg in enumerate(self.args):
-            if arg[-1] == '&&' and self.injectable:
-                failstop = True
-                arg = arg[:-1]
-            else:
-                failstop = False
-            self.status[i] = (subprocess.call(arg, shell = self.shell,
-                                               stdout = self.stdout,
-                                               stderr = self.stderr))
-            if failstop and self.status[i]:
-                break
-        self.exit = any(x for x in self.status)
-        self.complete = True
-        
-
-def run_subqueue(i, args, shell = False, verbose = False, injectable = False):
- #   if args:
-    s = Subqueue(args, shell = shell, 
-                 verbose = verbose, 
-                 injectable = injectable)
-    s.open()
-    return i, s.exit
-#    return [], -420
-
-
 def multisub(args_lists, processes = 1, shell = False, 
-             verbose = False, injectable = False, status = True):
-    import multiprocessing as mp
+             verbose = False):
     '''
     Inputs: list of arguments, integer of processes, subprocess `shell` bool
     Outputs: launches and monitors subprocesses and returns list of exit 
@@ -743,13 +645,46 @@ def multisub(args_lists, processes = 1, shell = False,
         IF there are not arguments in args_lists, wait until all processes
         are complete before exiting the function.
     '''
-    if not status:
-        with mp.Pool(processes = processes) as pool:
-            exit_pre = pool.starmap(run_subqueue, ((i, x, shell, verbose, injectable) \
-                                                    for i, x in enumerate(args_lists)))
+
+    if verbose:
+        stdout, stderr = None, None
     else:
-        with mp.Pool(processes = processes) as pool:
-            exit_pre = pool.starmap(run_subqueue, tqdm([(i, x, shell, verbose, injectable) \
-                                                    for i, x in enumerate(args_lists)], 
-                                                    total = len(args_lists)))
-    return [exit for i, exit in sorted(exit_pre, key = lambda x: x[0])]
+        stdout = subprocess.DEVNULL
+        stderr = subprocess.DEVNULL
+
+    running, outputs = [], []
+    if processes <= 0:
+        processes = 1
+
+    while args_lists: # while there are arguments populating arg_lists
+        while len(running) < processes and args_lists: # while not @ max
+        # processes
+            cmd = args_lists[0]
+            run_temp = subprocess.Popen(cmd , stdout = stdout, \
+                stderr = stderr, shell = shell) # run command
+            running.append([run_temp, cmd]) # add command to running
+            del args_lists[0] # delete from argument list to run
+
+        if len(args_lists) > 0: # if there are remaining arguments
+            for index, handle in enumerate(running): # check each status
+                handle[0].poll()
+                returncode = handle[0].returncode
+                if returncode is not None:
+                    outputs.append({
+                        'stdin': handle[1], 'code': returncode
+                        }) # add command and exit code
+                    del running[index] # remove from running
+                    break
+
+        else: # if there aren't remaining arguments
+            while len(running) > 0: # hold until all commands complete
+                handle = running[0]
+                handle[0].poll()
+                returncode = handle[0].returncode
+                if returncode is not None:
+                    outputs.append({
+                        'stdin': handle[1], 'code': returncode
+                        })
+                    del running[0]
+
+    return outputs # [{stdin: '', code: int()}]
