@@ -1,21 +1,17 @@
 #!/usr/bin/env python3
 
-# NEED source to reference the annotation source
-# NEED to error check FAA generation simply by file size
-
 import os
 import re
 import sys
 import copy
 import shutil
 import multiprocessing as mp
-from tqdm import tqdm
 from collections import Counter, defaultdict
 from mycotools.lib.kontools import gunzip, mkOutput, format_path, eprint, vprint
 from mycotools.lib.biotools import gff2list, list2gff, fa2dict, dict2fa, \
-    gff3Comps, gff2Comps, gtfComps
-from mycotools.lib.dbtools import mtdb, primaryDB, loginCheck
-from mycotools.utils.gtf2gff3 import main as gtf2gff3
+    gff3Comps, gff2Comps
+from mycotools.lib.dbtools import mtdb, masterDB, loginCheck
+from mycotools.curAnnotation import main as curRogue
 from mycotools.utils.curGFF3 import main as curGFF3
 from mycotools.utils.gff2gff3 import main as gff2gff3
 from mycotools.gff2seq import aamain as gff2seq
@@ -62,7 +58,7 @@ def move_biofile(old_path, ome, typ, wrk_dir, suffix = '' ):
         if not os.path.isfile(new_path) and os.path.isfile(old_path):
             copy_file(format_path(old_path), new_path)
         elif not os.path.isfile(new_path):
-            raise IOError(old_path, new_path)
+            raise IOError
         else:
             copy_file(format_path(old_path), new_path)
 
@@ -71,7 +67,7 @@ def move_biofile(old_path, ome, typ, wrk_dir, suffix = '' ):
 
 def gen_predb():
     example = [
-        'Fibsp1', 'fibpsy1', 'Fibularhizoctonia', 'psychrophila', 'CBS',
+        'Fibsp1', 'Fibularhizoctonia', 'psychrophila', 'CBS',
         '1.0', 'n', '<PATH/TO/ASSEMBLY>', '<PATH/TO/GFF3>', 'jgi',
         'no', '2018'
         ]
@@ -148,12 +144,6 @@ def read_predb(predb_path, spacer = '\t'):
             predb['species'][i] = 'sp.'
     return predb
 
-def sub_disallowed(data, disallowed = r"""[^\w\d]"""):
-    if data:
-        return re.sub(disallowed, '', data)
-    else:
-        return data
-
 def predb2mtdb(predb):
     infdb = mtdb()
     if not 'assemblyPath' in predb and 'fna' in predb:
@@ -164,24 +154,36 @@ def predb2mtdb(predb):
         predb['previous_ome'] = predb['ome']
     elif not 'previous_ome' in predb:
         predb['previous_ome'] = \
-            [None for x in predb[list(predb.keys())[0]]]
+            [None for x in predb['ome']]
     for i, code in enumerate(predb['genus']):
-        toAdd = {
-            'assembly_acc': predb['assembly_acc'][i],
-            'ome': sub_disallowed(predb['previous_ome'][i]),
-            'genus': sub_disallowed(predb['genus'][i]),
-            'species': sub_disallowed(predb['species'][i]),
-            'strain': re.sub(r'[^a-zA-Z0-9]', '', predb['strain'][i]),
-            'version': sub_disallowed(predb['version'][i]),
-            'biosample': sub_disallowed(predb['biosample'][i]),
-            'fna': predb['assemblyPath'][i],
-            'gff3': predb['gffPath'][i],
-            'source': predb['source'][i]
-            }
         if predb['published'][i]:
-            toAdd['published'] = predb['published'][i]
+            toAdd = {
+                'assembly_acc': predb['assembly_acc'][i],
+                'ome': predb['previous_ome'][i],
+                'genus': predb['genus'][i],
+                'species': predb['species'][i],
+                'strain': predb['strain'][i],
+                'version': predb['version'][i],
+                'biosample': predb['biosample'][i],
+                'fna': predb['assemblyPath'][i],
+                'gff3': predb['gffPath'][i],
+                'source': predb['source'][i],
+                'published': predb['published'][i]
+                }
         else:
-            toAdd['published'] = not predb['restriction'][i]
+            toAdd = {
+                'assembly_acc': predb['assembly_acc'][i],
+                'ome': predb['previous_ome'][i],
+                'genus': predb['genus'][i],
+                'species': predb['species'][i],
+                'strain': predb['strain'][i],
+                'version': predb['version'][i],
+                'biosample': predb['biosample'][i],
+                'fna': predb['assemblyPath'][i],
+                'gff3': predb['gffPath'][i],
+                'source': predb['source'][i],
+                'published': not predb['restriction'][i]
+                }
 #        if predb['published'][i]:
  #           toAdd['published'] = predb['published'][i]
         infdb = infdb.append(toAdd)
@@ -194,13 +196,13 @@ def gen_omes(
 
     t_failed = []
     ref_ome_check = [k for k,v in Counter(refdb['ome']).items() if v > 1]
-#    new_ome_check = [k for k,v in Counter(newdb['ome']).items() if v > 1 and k]
+    new_ome_check = [k for k,v in Counter(newdb['ome']).items() if v > 1 and k]
     if ref_ome_check:
         raise ValueError('corrupted reference database with non-unique omes: '
                         + str(ref_ome_check))
- #   elif new_ome_check:
-  #      raise ValueError('corrupted pre-database with non-unique omes: '
-   #                     + str(new_ome_check))
+    elif new_ome_check:
+        raise ValueError('corrupted pre-database with non-unique omes: '
+                        + str(new_ome_check))
     tax_list = list(set(refdb['ome']).union(forbidden))
     tax_count = {}
     for tax in tax_list:
@@ -220,8 +222,6 @@ def gen_omes(
     refdb_aas = refdb.set_index('assembly_acc')
     refdb_accs = set([x for x in list(refdb['assembly_acc']) if x])
     refdb_omes = set([x for x in list(refdb['ome'])])
-    refdb_nover = {re.sub(r'(^.{6}\d+)\.\d+', r'\1', x): x \
-                   for x in list(refdb['ome'])}
     for i, ome in enumerate(newdb['ome']):
         if not ome: # if there isn't an ome for this entry yet
             if newdb['assembly_acc'][i] in refdb_accs: # if this is an
@@ -269,7 +269,7 @@ def gen_omes(
             format_search = re.search(r'^[^\d_,\'";:\\\|\[\]\{\}\=\+\!@#\$\%\^' \
                                     + r'&\*\(\)]{6}\d+[^-_+=\\\|\{\[\}\]\:;' \
                                     + r'\'\"\,\<\>\?/\`\~\!\@\#\$\%\^\&\*\(' \
-                                    + r'\)\w\W]*\.{0,1}\d*$', ome) # crude format check
+                                    + r'\)\w\W]*$', ome) # crude format check
             if not format_search:
                 raise ValueError('invalid ome ' + ome)
             if ome in refdb_omes: # it's an update
@@ -281,17 +281,6 @@ def gen_omes(
                     new_ome = ome + '.1' # first modified version
                 eprint(spacer + ome + ' update -> ' + new_ome, flush = True)
                 newdb['ome'][i] = new_ome
-            elif ome in refdb_nover: # has a version, wasn't given in predb
-                version_ome = refdb_nover[ome]
-                v_search = re.search(r'\.(\d+)$', version_ome[6:])
-                if v_search:
-                    v = int(v_search[1]) + 1 # new version
-                    new_ome = ome + '.' + str(v)
-                else:
-                    raise TypeError('unknown error ' + ome)
-                eprint(spacer + ome + ' update -> ' + new_ome, flush = True)
-                newdb['ome'][i] = new_ome
-                    
 
     for i in reversed(todel):
         for key in mtdb.columns:
@@ -300,26 +289,12 @@ def gen_omes(
     return newdb, t_failed
 
 def cur_fna(cur_raw_fna_path, uncur_raw_fna_path, ome):
-    ome_ver = re.search(r'(.{6}\d+).(\d+)$', ome)
-    if ome_ver:
-        less_ome = ome_ver[1]
-        ver_num = ome_ver[2]
-    else:
-        less_ome = ome
-        ver_num = 0
     with open(cur_raw_fna_path + '.tmp', 'w') as out:
         with open(uncur_raw_fna_path, 'r') as in_:
             for line in in_:
                 if line.startswith('>'):
                     if not line.startswith('>' + ome + '_'):
-                        if re.search(r'^>' + less_ome + '_', line) is not None:
-                            new_line = line.replace('>' + less_ome + '_', '>' + ome + '_')
-                        elif re.search(r'^>' + less_ome + r'\.\d+_', line) is not None:
-                            new_line = re.sub(r'^>' + less_ome + r'\.\d+_', '>' + ome + '_',
-                                              line)
-                        else:
-                            new_line = '>' + ome + '_' + line[1:]
-                        out.write(new_line)
+                        out.write('>' + ome + '_' + line[1:])
                     else: # already curated
                         out.write(line)
                 else:
@@ -341,11 +316,11 @@ def cur_mngr(ome, raw_fna_path, raw_gff_path, wrk_dir,
         try:
             uncur_fna_path = move_biofile(raw_fna_path, ome, 'fa', wrk_dir + 'fna/',
                                       suffix = '.uncur')
-        except IOError as ie:
+        except IOError:
             eprint(spacer + ome + '|' + assembly_accession \
                  + ' failed FNA parsing', flush = True)
             if exit:
-                raise ie from None
+                raise IOError
             return ome, False, 'fna'
         cur_fna(cur_fna_path, uncur_fna_path, ome)
 
@@ -357,24 +332,19 @@ def cur_mngr(ome, raw_fna_path, raw_gff_path, wrk_dir,
         try:
             uncur_gff_path = move_biofile(raw_gff_path, ome, 'gff3', 
                                           wrk_dir + 'gff3/', suffix = '.uncur')
-        except IOError as ie:
+        except IOError:
             eprint(spacer + ome + '|' + assembly_accession \
                  + ' failed GFF3 parsing', flush = True)
-            if exit:
-                raise ie from None
-            return ome, False, 'gff3'
-        try:   
-            gff = gff2list(uncur_gff_path)
-        # malformatted
-        except IndexError:
             return ome, False, 'gff3'
+    
+        gff = gff2list(uncur_gff_path)
         try:
             gff_mngr(ome, gff, cur_gff_path, source, assembly_accession)
         except Exception as e: # catch all errors to continue script
             eprint(spacer + ome + '|' + assembly_accession \
                 + ' failed GFF3 curation', flush = True)
             if exit:
-                raise e from None
+                raise e
             return ome, False, 'gff3'
 
     # proteome FAAs
@@ -418,17 +388,6 @@ def gff_mngr(ome, gff, cur_path, source, assembly_accession):
         if re.search(gff3Comps()['id'], entry['attributes']):
             gffVer = 3
             alias = re.search(gff3Comps()['Alias'], entry['attributes'])
-            if alias is not None:
-                if entry['seqid'].startswith(ome + '_'):
-                    alias = True
-                else:
-                    alias = False # remove the old aliases
-                    entry['attributes'] = re.sub(r';?Alias=[^;]+', '',
-                                                entry['attributes'])
-            else:
-                break
-        elif re.search(gtfComps()['id'], entry['attributes']):
-            gffVer = 2.5
             break
         elif re.search(gff2Comps()['id'], entry['attributes']):
             gffVer = 2
@@ -447,33 +406,13 @@ def gff_mngr(ome, gff, cur_path, source, assembly_accession):
                         entry['attributes']
                         )
             else:
-#                try:
-                gff = curGFF3(gff, ome)
-  #              except:
-#                gff, trans_str, failed, flagged = curRogue(gff, ome)
+                gff, trans_str, failed, flagged = curRogue(gff, ome,
+                                                           cur_seqids = True)
         else:
             gff = curGFF3(gff, ome, cur_seqids = True)
-    elif gffVer == 2.5:
-        gff, trans_str, failed, flagged = gtf2gff3(gff, ome)
     else:
-        gff, errors = gff2gff3(gff, ome, assembly_accession, verbose = False)
-
-    ver_search = re.search(r'(.{6}\d+)\.(\d+)', ome)
-    if ver_search is not None:
-        less_ome = ver_search[1]
-        ome_ver = ver_search[2]
-    else:
-        less_ome = ome
-    for line in gff:
-        seqid = line['seqid']
-        if seqid.startswith(less_ome + '_'):
-            line['seqid'] = re.sub(r'^' + less_ome + '_', 
-                                 ome + '_', seqid)
-        elif re.search(r'^' + less_ome + r'\.\d+_', seqid):
-            line['seqid'] = re.sub(r'^' + less_ome + r'[^_]+_', 
-                                 ome + '_', seqid)
-        else:
-            line['seqid'] = ome + '_' + seqid
+        gff = gff2gff3(gff, ome, assembly_accession, verbose = False,
+                       cur_seqids = True)
 
     with open(cur_path + '.tmp', 'w') as out:
         out.write(list2gff(gff))
@@ -507,7 +446,7 @@ def main(
 
     vprint('\nCurating data', v = verbose, flush = True)
     with mp.Pool(processes = cpus) as pool:
-        cur_data = pool.starmap(cur_mngr, tqdm(cur_cmds, total = len(cur_cmds)))
+        cur_data = pool.starmap(cur_mngr, cur_cmds)
 
     for data in cur_data:
         if not data[1]:
@@ -540,9 +479,9 @@ if __name__ == '__main__':
         elif len(sys.argv) > 3:
             refDB = mtdb(format_path(sys.argv[3]))
         else:
-            refDB = mtdb(primaryDB())
+            refDB = mtdb(masterDB())
     else:
-        refDB = mtdb(primaryDB())
+        refDB = mtdb(masterDB())
 
     if set(sys.argv).intersection({'-s', '--skip'}):
         exit = False
@@ -559,6 +498,7 @@ if __name__ == '__main__':
     predb = read_predb(format_path(sys.argv[1]), spacer = '\t')
     out_dir, wrk_dir = prep_output(os.path.dirname(format_path(sys.argv[1])))
 
+
     omedb, failed = main(predb, refDB, wrk_dir, exit = exit, verbose = True)
 
     from mycotools.lib.dbtools import gather_taxonomy, assimilate_tax
